@@ -38,10 +38,6 @@
 static QString version = QStringLiteral ("2.6.0");
 
 int main ( int argc, char **argv ) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-	QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-	QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
 	QApplication app(argc, argv);
 
 	KLocalizedString::setApplicationDomain("knights");
